@@ -8,6 +8,7 @@ final class MessageSystemAttributeName
     public const APPROXIMATE_FIRST_RECEIVE_TIMESTAMP = 'ApproximateFirstReceiveTimestamp';
     public const APPROXIMATE_RECEIVE_COUNT = 'ApproximateReceiveCount';
     public const AWSTRACE_HEADER = 'AWSTraceHeader';
+    public const DEAD_LETTER_QUEUE_SOURCE_ARN = 'DeadLetterQueueSourceArn';
     public const MESSAGE_DEDUPLICATION_ID = 'MessageDeduplicationId';
     public const MESSAGE_GROUP_ID = 'MessageGroupId';
     public const SENDER_ID = 'SenderId';
@@ -21,6 +22,7 @@ final class MessageSystemAttributeName
             self::APPROXIMATE_FIRST_RECEIVE_TIMESTAMP => true,
             self::APPROXIMATE_RECEIVE_COUNT => true,
             self::AWSTRACE_HEADER => true,
+            self::DEAD_LETTER_QUEUE_SOURCE_ARN => true,
             self::MESSAGE_DEDUPLICATION_ID => true,
             self::MESSAGE_GROUP_ID => true,
             self::SENDER_ID => true,
