@@ -2,6 +2,8 @@
 
 namespace AsyncAws\Sqs\ValueObject;
 
+use AsyncAws\Core\Exception\InvalidArgument;
+
 /**
  * Gives a detailed description of the result of an action on each entry in the request.
  */
@@ -9,21 +11,29 @@ final class BatchResultErrorEntry
 {
     /**
      * The `Id` of an entry in a batch request.
+     *
+     * @var string
      */
     private $id;
 
     /**
      * Specifies whether the error happened due to the caller of the batch API action.
+     *
+     * @var bool
      */
     private $senderFault;
 
     /**
      * An error code representing why the action failed on this entry.
+     *
+     * @var string
      */
     private $code;
 
     /**
      * A message explaining why the action failed on this entry.
+     *
+     * @var string|null
      */
     private $message;
 
@@ -37,12 +47,20 @@ final class BatchResultErrorEntry
      */
     public function __construct(array $input)
     {
-        $this->id = $input['Id'] ?? null;
-        $this->senderFault = $input['SenderFault'] ?? null;
-        $this->code = $input['Code'] ?? null;
+        $this->id = $input['Id'] ?? $this->throwException(new InvalidArgument('Missing required field "Id".'));
+        $this->senderFault = $input['SenderFault'] ?? $this->throwException(new InvalidArgument('Missing required field "SenderFault".'));
+        $this->code = $input['Code'] ?? $this->throwException(new InvalidArgument('Missing required field "Code".'));
         $this->message = $input['Message'] ?? null;
     }
 
+    /**
+     * @param array{
+     *   Id: string,
+     *   SenderFault: bool,
+     *   Code: string,
+     *   Message?: null|string,
+     * }|BatchResultErrorEntry $input
+     */
     public static function create($input): self
     {
         return $input instanceof self ? $input : new self($input);
@@ -67,4 +85,12 @@ final class BatchResultErrorEntry
     {
         return $this->senderFault;
     }
+
+    /**
+     * @return never
+     */
+    private function throwException(\Throwable $exception)
+    {
+        throw $exception;
+    }
 }
